
package java2D1complete;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.GradientPaint;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.geom.Rectangle2D;
import java.util.Iterator;
import javax.swing.*;
import java.awt.geom.*;
import java.awt.image.BufferedImage;
import java.util.List;

/**
 * Komponente, auf der gezeichnet wird
 * @author arnd
 */
public class RenderCanvas extends Canvas {
    
    private RenderingHints qualityHints;
    private Graphics2D graphics2D;
    private ObjectRenderer objectRenderer;
    private CanvasModel cModel;
    
    
    RenderCanvas(CanvasModel cm) {
        cModel = cm;
        setBackground(Color.black);
        this.objectRenderer = new ObjectRenderer();
        this.qualityHints = new RenderingHints(null);        
        
        
        addMouseListener(new MouseAdapter() {
            public void mousePressed(MouseEvent e) {
                
                int x = e.getX();
                int y = e.getY();
                
                AffineTransform pos = AffineTransform.getTranslateInstance(x,y);
                pos.rotate(State.getAngle()*Math.PI/180, 75, 75);
                GeometricObject go = new GeometricObject(State.getShapeOption(),State.getFillOption(),  pos);
                cModel.addObject(go);
                
                if(State.isAntialiasingEnabled()) {
                    qualityHints.put(RenderingHints.KEY_ANTIALIASING,RenderingHints.VALUE_ANTIALIAS_ON);
                } else {
                    qualityHints.put(RenderingHints.KEY_ANTIALIASING,RenderingHints.VALUE_ANTIALIAS_OFF);
                }
                if(State.isDitheringEnabled()) {
                    qualityHints.put(RenderingHints.KEY_DITHERING,RenderingHints.VALUE_DITHER_ENABLE);
                } else {
                    qualityHints.put(RenderingHints.KEY_DITHERING, RenderingHints.VALUE_DITHER_DISABLE);
                }
                repaint();
            }
        });

        
    }
    
    
    public void paint(Graphics g) {
        //Cast Graphics g to Graphics2D graphics2D
        graphics2D = (Graphics2D) g;
        
        //RenderingHints setzen
        graphics2D.setRenderingHints(qualityHints);
        
        
        List objects = cModel.getObjects();
        Iterator it = objects.iterator();
        while (it.hasNext()) {
            this.objectRenderer.renderObject(graphics2D, (GeometricObject)it.next());
        }
        
        
    }
    
    
    public Dimension getPreferredSize() {
        return new Dimension(400,400);
    }
}
